/*! \file
	== UTF-8 Utility Functions ==
	
	These functions allow management of UTF-8 characters,
	and provide conversion from UTF to to 16-bit integers.
	
	Pointer argument is to a memory buffer, which must always contain
	complete UTF sequences. Null byte (terminator) returns null.

	These assume valid UTF8 strings!
	If non-UTF8 is encountered, it does its best, but will probably be wrong...
	[UTF-8 of more than 3-bytes is not handled. It can't be
	converted to 16-bits, and is assumed to be rare.]
*/

/*! Returns the 16-bit code for the (up to 3-byte) UTF-8 character
pointed to by the argument.  The argunent is incremented appropriately */
int utf2istep(char *& pt);

/*! Returns the 16-bit code for the (up to 3-byte) UTF-8 character
pointed to by the argument.  Argument is not changed */
int utf2i(char * pt);

/*! Steps over the current UTF-8 character pointed to by the argument.
The incremented argunent is returned */
char * utfstep(char *& pt, int n=1);

/*! Returns the number of UTF-8 characters (not bytes) in the
null-terminated string pointed to by the argument. */
long utflen(char *pt);

